@@ -1,8 +1,7 @@
 /*
- * segatex_editor SELinux tool.
+ * segatex SELinux tool.
  *
  * Copyright (C) 2007 Shintaro Fujiwara 
- * shintaro.fujiwara@gmai.com
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,14 +25,13 @@
 
 class ParseLinesServices: public ParseLines
 {
-    Q_OBJECT
+	Q_OBJECT
 public:
-    ParseLinesServices();
-    ParseLinesServices(QSplitter*&);
-    ~ParseLinesServices();
+	ParseLinesServices();
+	ParseLinesServices(QSplitter*&);
 public slots:
-    void parse_services();
-    void break_services();
+	void parse_services();
+	void break_services();
 };
 
 #endif
